@@ -19,4 +19,4 @@ SOFTWARE.
 """
 
 
-from .snn import *
\ No newline at end of file
+from .snnpy import *
\ No newline at end of file
